#
# spec file for package dateutils
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define xversion 0.4.1

%define have_octave 0

%if 0%{?suse_version} >= 1220 && 0%{?suse_version} != 1315
%define have_octave 1
%ifarch aarch64
%if 0%{?suse_version} <= 1310
%define have_octave 0
%endif
%endif
%ifnarch i586 x86_64
%if 0%{?suse_version} < 1310
%define have_octave 0
%endif
%endif
%endif

%if 0%{?fedora_version} >= 19
%define have_octave 1
%endif

Name:           dateutils
Version:        0.4.1
Release:        1.1
Summary:        Nifty command line date and time utilities
License:        BSD-3-Clause
Group:          Productivity/Text/Utilities
Url:            https://github.com/hroptatyr/dateutils/
Source:         https://bitbucket.org/hroptatyr/dateutils/downloads/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch1:         0001-fix-when-printing-zones-transitioning-at-INT_MAX-in-.patch
BuildRequires:  pkgconfig
BuildRequires:  xz
%if 0%{?suse_version}
BuildRequires:  timezone
%endif
%if %have_octave
BuildRequires:  octave-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  info

%description
Dateutils are a bunch of tools that revolve around fiddling with dates
and times in the command line with a strong focus on use cases that
arise when dealing with large amounts of financial data. Their target
market is shell scripts that need date calculations or calendar
conversions, and as such they are highly pipe-able and modeled after
their well-known cousins (e.g. dtest vs. test, or dgrep vs. grep).

%if %have_octave
%package octave
Summary:        Dateutils functions for matlab and octave
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       octave

%description octave
Dateutils can be used from within matlab or ocatave.
%endif

%prep
%setup -q -n %{name}-%{xversion}
%patch1 -p1

%build
%configure \
    --docdir=%{_docdir}/%{name} \
%if %have_octave
    --enable-contrib \
%endif
    ignorethisline=xxx
make V=1

%install
%{?make_install} %{!?make_install:make install DESTDIR=%{buildroot}}
rm -f %{buildroot}%{_infodir}/dir
rm -f %{buildroot}%{_libdir}/octave/site/oct/*/dateutils/tzconv.la

%check
if ! make check; then
    cat test/test-suite.log
    exit 1
fi

%clean
rm -rf %{buildroot}

# How to make that info stuff portable?
%if 0%{?install_info:1} > 0

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info*

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info*
%endif

%files
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}
%{_bindir}/dadd
%{_bindir}/dconv
%{_bindir}/ddiff
%{_bindir}/dgrep
%{_bindir}/dround
%{_bindir}/dseq
%{_bindir}/dsort
%{_bindir}/dtest
%{_bindir}/dzone
%{_bindir}/dateadd
%{_bindir}/dateconv
%{_bindir}/datediff
%{_bindir}/dategrep
%{_bindir}/dateround
%{_bindir}/dateseq
%{_bindir}/datesort
%{_bindir}/datetest
%{_bindir}/datezone
%{_bindir}/strptime
%dir %{_datadir}/dateutils/
%{_datadir}/dateutils/locale
%{_datadir}/dateutils/*.tzmcc
%doc %{_infodir}/%{name}.info*
%doc %{_mandir}/man1/%{name}.1*
%doc %{_mandir}/man1/dadd.1*
%doc %{_mandir}/man1/dconv.1*
%doc %{_mandir}/man1/ddiff.1*
%doc %{_mandir}/man1/dgrep.1*
%doc %{_mandir}/man1/dround.1*
%doc %{_mandir}/man1/dseq.1*
%doc %{_mandir}/man1/dsort.1*
%doc %{_mandir}/man1/dtest.1*
%doc %{_mandir}/man1/dzone.1*
%doc %{_mandir}/man1/dateadd.1*
%doc %{_mandir}/man1/dateconv.1*
%doc %{_mandir}/man1/datediff.1*
%doc %{_mandir}/man1/dategrep.1*
%doc %{_mandir}/man1/dateround.1*
%doc %{_mandir}/man1/dateseq.1*
%doc %{_mandir}/man1/datesort.1*
%doc %{_mandir}/man1/datetest.1*
%doc %{_mandir}/man1/datezone.1*
%doc %{_mandir}/man1/strptime.1*

%if %have_octave
%files octave
%defattr(-,root,root)
%dir %{_libdir}/octave/site/oct/*/dateutils/
%{_libdir}/octave/site/oct/*/dateutils/tzconv.m
%{_libdir}/octave/site/oct/*/dateutils/tzconv.mex
%endif

%changelog
* Mon Apr  3 2017 sweet_f_a@gmx.de
- fix incompatibility with tzdata/tzcode >= 2017a,
  0001-fix-when-printing-zones-transitioning-at-INT_MAX-in-.patch
* Thu Dec 15 2016 sweet_f_a@gmx.de
- bump version 0.4.1, this is a bugfix release.
  * Bugfixes:
  - bug/50, keep end-of-term (ultimo) property in dateseq(1)
  - allow today/now for ywd dates in 1 parameter dateseq(1)
  - allow different calendars for start and end date in dateseq(1)
  - round time in dateround(1) in zone then convert --from-zone
  - allow SPC padded numerals in %%d input format
  * See info page examples and/or README.
- remove patch which is upstream now:
  0001-Revert-chore-be-more-portable-in-sxe-matlab.m4.patch
* Wed Jun 15 2016 sweet_f_a@gmx.de
- fix .mex file extension for octave plugin,
  0001-Revert-chore-be-more-portable-in-sxe-matlab.m4.patch
- explicit octave plugin file list
- remove *.la files
* Thu Jun  2 2016 sweet_f_a@gmx.de
- bump version 0.4.0, this is a feature release.
  * Bugfixes:
  - document %%g/%%G format specifiers
  - bug/42, accept NUL characters in input
  - bug/45, correctly display Gregorian and ISO week dates in one
    line
  - bug/46, adhere to ISO group's official formatting of week
    dates
  - bug/47, allow rounding of Epoch based timestamps
  - bug/48, avoid crash for void input to strptime(3)
  * Features:
  - datetest supports --isvalid to conditionalise on date/time
    parsing
  - all tools support --from-locale to parse localised input
  - tools with output formatting support --locale to format
    output according to locale
  * See info page examples and/or README.
* Fri Jan 22 2016 sweet_f_a@gmx.de
- bump version 0.3.5, this is a bugfix release.
  * Bugfixes:
  - bug/40, distinguish between numerals-only dates and durations
  - tests will succeed independent of current date
  * See info page examples and/or README.
- remove dateutils-0.3.4-fix-test-126.patch (upstream applied)
* Sun Jan 10 2016 antoine.belvire@laposte.net
- Fix build:
  * add dateutils-0.3.4-fix-test-126.patch (from upstream)
    (bnc#966644)
* Wed Sep  2 2015 sweet_f_a@gmx.de
- remove old obsoletes line for devel package
* Mon Aug 31 2015 sweet_f_a@gmx.de
- bump version 0.3.4, this is a bugfix release.
  * Bugfixes:
  - bug/39, MacOSX endianness detection
  - bug/38, ddiff day-only durations on date/times
  - dadd +2m bug is fixed, regression
  * See info page examples and/or README.
- remove patches (upstream applied):
  * 0001-fix-build-for-compilers-without-anonymous-struct-ini.patch
  * 0002-fix-dateadd-unix-timestamp-bug.patch
* Sun Aug  2 2015 mpluskal@suse.com
- Correct previous changelog entries (incorrect patch names)
* Mon Jun 15 2015 sweet_f_a@gmx.de
- add 0002-fix-dateadd-unix-timestamp-bug.patch
* Wed Jun 10 2015 sweet_f_a@gmx.de
- bump version 0.3.3, this is a feature release.
  * Features:
  - to clarify purpose and avoid name clashes prefix binaries
    with "date". This results in: dateadd, dateconv, ... etc.
  - provide compatibilty through configure switch --with-old-names
  - provide single digit years through %%_y
  - allow rounding of ISO-week dates (ywd) to week numbers
  * Bugfixes:
  - dashes behind a date do not count as tz indicator
  - UTC/TAI/GPS special coordinated zones work on systems without
    leap second support
  * See info page examples and/or README
- add 0001-fix-build-for-compilers-without-anonymous-struct-ini.patch
  to support broken compilers (SLE 11, RHEL 6, etc.)
* Thu Mar  5 2015 sweet_f_a@gmx.de
- bump version 0.3.2, this is a bugfix release.
  * Bugfixes:
  - out of range minutes will be discarded
  - bug 30 (malicious input crashes dconv) has been fixed
  * Features:
  - military midnight stamps are supported (T24:00:00)
  - 8601 ordinal dates (year + doy) are recognised directly
    (`-f yd`)
  - strptime(1) can behave in a locale-dependent way
  * See info page examples and/or README.
* Fri Jan 16 2015 sweet_f_a@gmx.de
- sort out distros with and without octave
* Tue Oct  7 2014 sweet_f_a@gmx.de
- bump version 0.3.1, this is a bugfix release.
  * Bugfixes:
  - octave/matlab code is distributed fully
  - negative durations with refined units are minus-signed only
    once
  - ddiff is entirely anticommutative now
  - tests don't fail if zones don't exist on the build system
  - dseq with empty ranges will no longer produce output (just as
    seq(1))
  - arbitrary integers are not interpreted as time anymore
  - when converting from zone info properly clear zone difference
    for %%Z
  - dseq(1) will automatically resort to +1mo and +1y iterators
    for wildcarded ymd dates
  - dadd(1)'ing ywd dates with output as ymd works properly now
  * Features:
  - ddiff can output nanosecond diffs
  - automatic fix-up of dates is documented now
  - parser errors and fix ups are reported through return code 2
  - dseq with no `-f|--format` stays in the calendric system of
    the start value instead of converting all output to ymd
  * See info page examples and/or README.
* Tue Aug 26 2014 sweet_f_a@gmx.de
- bump version 0.3.0, this is a feature release.
  * Features:
  - dgrep supports time zones both for the expression and the
    input
  - timezones can be specified by alternative codes and
    [tzmap files][1]
  - new tool dzone to inspect date/times in multiple timezones in
    bulk
  - new tool dsort to sort input chronologically
  - gengetopt and help2man maintainer dependencies removed
  - lilian/julian inputs via `-i ldn` and `-i jdn`
  - ymcw dates now follow ISO 8601 in using 07 to denote Sunday
  * Bugfixes:
  - ddiff takes differences between a unix epoch stamp and a
    date/time
  - zone converter assigns correct sign to zone difference when
    using %%Z
  - weekdays are properly calculated from epoch stamps (issue 24)
  * See info page examples and/or README.
    [1]: http://www.fresse.org/dateutils/tzmaps.html
- enable Octave/Matlab plugin
- remove useless devel package
* Wed Jan 29 2014 sweet_f_a@gmx.de
- bump version 0.2.7, this is a feature release.
  * Features:
  - dgrep supports -v|--invert-match like grep
  - output specifier %%G is supported for compatibility with POSIX
  - ddiff calculates year-day differences
  - ddiff calculates ISO-week date differences
  - ddiff output can be zero and space padded through 0 and SPC
    modifier
  - zoneinfo database on AIX >= 6.1 is taken into account
  * Bug fixes:
  - ddiff can calculate full year differences, [issue 21][1] fixed
  - dseq now accepts %%W, %%V output formats, [issue 22][2] fixed
  - builds with clang >= 3.3 work again, [clang bug 18028][3]
  * See info page examples and/or README.
    [1]: https://github.com/hroptatyr/dateutils/issues/21
    [2]: https://github.com/hroptatyr/dateutils/issues/22
    [3]: http://llvm.org/bugs/show_bug.cgi?id=18028
* Tue Oct 29 2013 sweet_f_a@gmx.de
- bump version 0.2.6, this is a bug fix release.
  * issue 19, -q|--quiet no longer sends some commands into an
    inf-loop
  * netbsd test failures are fixed (due to missing leap seconds)
  * AIX builds are supported (getopt_long() is part of the code
    now)
  * internally the test harness is migrated to the cli-testing tool
    this fixes an issue when tests are run in directories with odd
    names (spaces, dollar signs, etc. in the path name)
  * See info page examples and/or README.
* Thu Jul 25 2013 sweet_f_a@gmx.de
- bump version 0.2.5, this is a bug fix release.
  * issue 18, long inputs to a short specifier string will yield an
    error
  * consume zone specs (a la +1200) in the input via %%Z specifier
  * ddiff's stdin stamps will undergo conversion according to
  - -from-zone
  * clean up dist for inclusion in debian
  * See info page examples and/or README.-
* Thu Feb  7 2013 sweet_f_a@gmx.de
- bump version 0.2.4, this is a bug fix release.
  * added special output format `jdn' and `ldn' for julian/lilian
    day number
  * multiple occurrences of date/times within one line are now all
    processed rather than only the first occurrence
  * zone difference specifier (%%Z) is supported for parsing and
    printing
  * matlab zone converter tzconv has been added
  * building with icc 13 works now
  * many gcc warnings are fixed
  * See info page examples and/or README.
* Fri Sep 14 2012 sweet_f_a@gmx.de
- bump version 0.2.3, this is a bug fix and feature release.
  * ISO 8601 week dates are now first class objectsi
    (of type DT_YWD)
  * introduce %%rY specifier to denote years in calendars that
    deviate from the Gregorian year
  * dgrep accepts short-hand inputs (today, now, etc.) and also
    inputs as specified by -i
  * dadd'ing months and years to YMCW dates works now
  * zoneinfo files with only transitions in the past are handled
    properly (bug #10)
  * dseq with just 1 argument is working properly (story #36051287)
  * See info page examples and/or README.
* Fri Jul 20 2012 sweet_f_a@gmx.de
- bump version 0.2.2, this is a bug fix and feature release.
  * Olson's zoneinfo database files are checked for at configure
    time
  * leap-aware calculations use shipped leapseconds file
  * ddiff and dadd can take leap-second transitions into account
  * issue 7: ddiff without arguments does not segfault
  * issue 8: dadd copes with huge summands
  * issue 9: dadd stumbles on ymcw dates
  * bug 33104651: bday negative difference A > B ddiff A B -f %%db
    is wrong
  * See info page examples and/or README.
* Tue Jun 19 2012 sweet_f_a@gmx.de
- bump version 0.2.1, this is a bug fix and feature release.
  * The dadd tool now supports mass-adding durations (from stdin).
  * The ddiff tool is now time zone aware.
  * A new tool dround is added to round dates or times or
    date-times to the next occurrence of what's given as
    round-spec.
  * Bug fixes:
  - issue 7: ddiff without arguments does not segfault
  - issue 8: dadd copes with huge summands
  * See info page examples and/or README.
* Tue Apr 10 2012 sweet_f_a@gmx.de
- bump version 0.2.0, this is a feature release.
  * The distinction between binaries for date, time and date-time
    processing is cleared up by a unified set of tools, prefixed
    with `d'.
    Thus:
    dadd + tadd -> dadd
    dconv + tconv + dtconv -> dconv
    ddiff + tdiff -> ddiff
    dgrep + tgrep -> dgrep
    dseq + tseq -> dseq
    dtest + ttest -> dtest
  * Furthermore, all tools now fully cope with dates, times and
    date-times.
  * Virtual timezones have been added (use `GPS' or `TAI').
  * See info page examples and/or README.
* Fri Mar 23 2012 sweet_f_a@gmx.de
- bump version 0.1.10, this is a bug fix release.
  * account for big-endian machines
  * GNUisms (mempcpy() and getline()) are removed
  * inf-loop in tseq is fixed (bug #6)
  * nanoseconds are preserved upon time zone conversion
- add byteswap.patch to fix build for old distros
* Wed Feb  1 2012 sweet_f_a@gmx.de
- bump version 0.1.9, this is a bug fix release.
  * The code for date addition is refactored, with it a new
    duration type is introduced, DT_MD, to capture larger month and
    day summands.
* Tue Jan  3 2012 sweet_f_a@gmx.de
- bump version 0.1.8, this is a bug fix release.
  * A bit fiddling bug gave erroneous results in `dconv now'.
  * Furtherly, date expressions (for dgrep et al.) can now be
    arbitrarily joined with conjunctions (&&) and disjunctions (||)
    as well as negations (!).
* Thu Oct 27 2011 sweet_f_a@gmx.de
- bump version 0.1.7, this is a bug fix release.
* Fri Oct 21 2011 sweet_f_a@gmx.de
- bump version 0.1.6
* Wed Sep 14 2011 sweet_f_a@gmx.de
- initial package datetools 0.1.2
